@@ -110,7 +110,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 23 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
 
 
 /* 
@@ -136,22 +136,17 @@
 */
 
 #include "config.h"
-#include "core/math.h"
 
+#include "core/math.h"
 #include "internal/hacks.h"
 #include "io/dl-header.h"
 #include "io/parsers/dl-parser.h"
+#include "io/parsers/dl-lexer.h"
 
 #include <stdio.h>
 
-#define yyscan_t void*
-
-int igraph_dl_yylex(YYSTYPE* lvalp, YYLTYPE* llocp, void* scanner);
 int igraph_dl_yyerror(YYLTYPE* locp, igraph_i_dl_parsedata_t* context, 
 		      const char *s);
-char *igraph_dl_yyget_text (yyscan_t yyscanner );
-int igraph_dl_yyget_leng (yyscan_t yyscanner );
-
 int igraph_i_dl_add_str(char *newstr, int length, 
 			igraph_i_dl_parsedata_t *context);
 int igraph_i_dl_add_edge(long int from, long int to,
@@ -186,13 +181,13 @@ extern igraph_real_t igraph_pajek_get_number(const char *str, long int len);
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 88 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
 {
   long int integer;
   igraph_real_t real;
 }
 /* Line 193 of yacc.c.  */
-#line 196 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/dl-parser.c"
+
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -217,7 +212,7 @@ typedef struct YYLTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 221 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/dl-parser.c"
+
 
 #ifdef short
 # undef short
@@ -531,13 +526,13 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   113,   113,   115,   115,   117,   117,   119,   120,   121,
-     124,   124,   126,   126,   128,   129,   130,   133,   134,   140,
-     140,   145,   145,   147,   157,   159,   161,   161,   163,   167,
-     171,   176,   180,   182,   183,   184,   185,   186,   189,   190,
-     193,   195,   199,   202,   203,   206,   208,   212,   215,   231,
-     233,   234,   235,   236,   237,   240,   241,   244,   246,   249,
-     249,   255,   256,   259,   261,   265,   265
+       0,   108,   108,   110,   110,   112,   112,   114,   115,   116,
+     119,   119,   121,   121,   123,   124,   125,   128,   129,   135,
+     135,   140,   140,   142,   152,   154,   156,   156,   158,   162,
+     166,   171,   175,   177,   178,   179,   180,   181,   184,   185,
+     188,   190,   194,   197,   198,   201,   203,   207,   210,   226,
+     228,   229,   230,   231,   232,   235,   236,   239,   241,   244,
+     244,   250,   251,   254,   256,   260,   260
 };
 #endif
 
@@ -1552,57 +1547,57 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 113 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { context->n=(yyvsp[(3) - (7)].integer); ;}
     break;
 
   case 7:
-#line 119 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { context->type=IGRAPH_DL_MATRIX; ;}
     break;
 
   case 8:
-#line 120 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { context->type=IGRAPH_DL_EDGELIST1; ;}
     break;
 
   case 9:
-#line 121 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { context->type=IGRAPH_DL_NODELIST1; ;}
     break;
 
   case 10:
-#line 124 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 11:
-#line 124 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 14:
-#line 128 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { ;}
     break;
 
   case 15:
-#line 129 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { ;}
     break;
 
   case 16:
-#line 130 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { ;}
     break;
 
   case 17:
-#line 133 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 18:
-#line 134 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { 
 	      igraph_i_dl_add_str(igraph_dl_yyget_text(scanner), 
                                   igraph_dl_yyget_leng(scanner), 
@@ -1610,12 +1605,12 @@ yyreduce:
     break;
 
   case 19:
-#line 140 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 20:
-#line 140 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
   context->from += 1;
   context->to = 0;
@@ -1623,12 +1618,12 @@ yyreduce:
     break;
 
   case 22:
-#line 145 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { ;}
     break;
 
   case 23:
-#line 147 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
   if (igraph_dl_yyget_text(scanner)[0]=='1') {
     IGRAPH_CHECK(igraph_vector_push_back(&context->edges, 
@@ -1641,24 +1636,24 @@ yyreduce:
     break;
 
   case 24:
-#line 157 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 25:
-#line 159 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 28:
-#line 163 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { igraph_i_dl_add_str(igraph_dl_yyget_text(scanner), 
                                    igraph_dl_yyget_leng(scanner), 
 				   context); ;}
     break;
 
   case 29:
-#line 167 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
 	         context->from += 1; 
 		 context->to = 0;
@@ -1666,7 +1661,7 @@ yyreduce:
     break;
 
   case 30:
-#line 171 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { 
 	         context->from += 1; 
 		 context->to = 0;
@@ -1674,100 +1669,100 @@ yyreduce:
     break;
 
   case 31:
-#line 176 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { ;}
     break;
 
   case 32:
-#line 180 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 33:
-#line 182 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 34:
-#line 183 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 35:
-#line 184 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 36:
-#line 185 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 37:
-#line 186 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 38:
-#line 189 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 39:
-#line 190 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 40:
-#line 193 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
                    igraph_i_dl_add_edge_w((yyvsp[(1) - (4)].integer)-1, (yyvsp[(2) - (4)].integer)-1, (yyvsp[(3) - (4)].real), context); ;}
     break;
 
   case 41:
-#line 195 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
 		   igraph_i_dl_add_edge((yyvsp[(1) - (3)].integer)-1, (yyvsp[(2) - (3)].integer)-1, context);
 ;}
     break;
 
   case 42:
-#line 199 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { (yyval.integer)=igraph_pajek_get_number(igraph_dl_yyget_text(scanner), 
 					  igraph_dl_yyget_leng(scanner)); ;}
     break;
 
   case 43:
-#line 202 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 44:
-#line 203 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 45:
-#line 206 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
                           igraph_i_dl_add_edge_w((yyvsp[(1) - (4)].integer), (yyvsp[(2) - (4)].integer), (yyvsp[(3) - (4)].real), context); ;}
     break;
 
   case 46:
-#line 208 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
 			  igraph_i_dl_add_edge((yyvsp[(1) - (3)].integer), (yyvsp[(2) - (3)].integer), context);
  ;}
     break;
 
   case 47:
-#line 212 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { (yyval.real)=igraph_pajek_get_number(igraph_dl_yyget_text(scanner), 
 					 igraph_dl_yyget_leng(scanner)); ;}
     break;
 
   case 48:
-#line 215 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
   /* Copy label list to trie, if needed */
   if (igraph_strvector_size(&context->labels) != 0) {
@@ -1784,63 +1779,63 @@ yyreduce:
     break;
 
   case 49:
-#line 231 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 50:
-#line 233 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 51:
-#line 234 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 52:
-#line 235 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 53:
-#line 236 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 54:
-#line 237 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 55:
-#line 240 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 56:
-#line 241 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 57:
-#line 244 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 58:
-#line 246 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { context->from=igraph_pajek_get_number(igraph_dl_yyget_text(scanner),
 							  igraph_dl_yyget_leng(scanner)); ;}
     break;
 
   case 59:
-#line 249 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 60:
-#line 249 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { 
   IGRAPH_CHECK(igraph_vector_push_back(&context->edges, 
 				       context->from-1)); 
@@ -1849,29 +1844,29 @@ yyreduce:
     break;
 
   case 61:
-#line 255 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 62:
-#line 256 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {;}
     break;
 
   case 63:
-#line 259 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     { ;}
     break;
 
   case 64:
-#line 261 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
   context->from=(yyvsp[(1) - (1)].integer);
  ;}
     break;
 
   case 66:
-#line 265 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
     {
   IGRAPH_CHECK(igraph_vector_push_back(&context->edges, 
 				       context->from));
@@ -1881,7 +1876,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1885 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/dl-parser.c"
+
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2101,7 +2096,7 @@ yyreturn:
 }
 
 
-#line 271 "/Users/tamas/dev/igraph/igraph/src/io/dl-parser.y"
+
 
 
 int igraph_dl_yyerror(YYLTYPE* locp, igraph_i_dl_parsedata_t* context, 
