@@ -88,7 +88,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 23 "/Users/tamas/dev/igraph/igraph/src/io/ncol-parser.y"
+
 
 
 /* 
@@ -117,24 +117,19 @@
 #include <string.h>
 
 #include "igraph_types.h" 
-#include "core/math.h"
 #include "igraph_memory.h"
 #include "igraph_error.h"
 #include "config.h"
 
+#include "core/math.h"
 #include "io/ncol-header.h"
 #include "io/parsers/ncol-parser.h"
+#include "io/parsers/ncol-lexer.h"
 #include "internal/hacks.h"
 
-#define yyscan_t void*
-
-int igraph_ncol_yylex(YYSTYPE* lvalp, YYLTYPE* llocp, 
-		      void* scanner);
 int igraph_ncol_yyerror(YYLTYPE* locp, 
 			igraph_i_ncol_parsedata_t *context, 
 			const char *s);
-char *igraph_ncol_yyget_text (yyscan_t yyscanner );
-int igraph_ncol_yyget_leng (yyscan_t yyscanner );
 igraph_real_t igraph_ncol_get_number(const char *str, long int len);
 
 #define scanner context->scanner
@@ -160,13 +155,13 @@ igraph_real_t igraph_ncol_get_number(const char *str, long int len);
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 84 "/Users/tamas/dev/igraph/igraph/src/io/ncol-parser.y"
+
 {
   long int edgenum;
   double weightnum;
 }
 /* Line 193 of yacc.c.  */
-#line 170 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/ncol-parser.c"
+
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -191,7 +186,7 @@ typedef struct YYLTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 195 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/ncol-parser.c"
+
 
 #ifdef short
 # undef short
@@ -477,7 +472,7 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    98,    98,    99,   100,   103,   108,   116,   121
+       0,    93,    93,    94,    95,    98,   103,   111,   116
 };
 #endif
 
@@ -1407,7 +1402,7 @@ yyreduce:
   switch (yyn)
     {
         case 5:
-#line 103 "/Users/tamas/dev/igraph/igraph/src/io/ncol-parser.y"
+
     { 
            igraph_vector_push_back(context->vector, (yyvsp[(1) - (3)].edgenum));
            igraph_vector_push_back(context->vector, (yyvsp[(2) - (3)].edgenum));
@@ -1416,7 +1411,7 @@ yyreduce:
     break;
 
   case 6:
-#line 108 "/Users/tamas/dev/igraph/igraph/src/io/ncol-parser.y"
+
     { 
            igraph_vector_push_back(context->vector, (yyvsp[(1) - (4)].edgenum));
            igraph_vector_push_back(context->vector, (yyvsp[(2) - (4)].edgenum));
@@ -1426,7 +1421,7 @@ yyreduce:
     break;
 
   case 7:
-#line 116 "/Users/tamas/dev/igraph/igraph/src/io/ncol-parser.y"
+
     { igraph_trie_get2(context->trie, 
 				   igraph_ncol_yyget_text(scanner),
 				   igraph_ncol_yyget_leng(scanner), 
@@ -1434,14 +1429,14 @@ yyreduce:
     break;
 
   case 8:
-#line 121 "/Users/tamas/dev/igraph/igraph/src/io/ncol-parser.y"
+
     { (yyval.weightnum)=igraph_ncol_get_number(igraph_ncol_yyget_text(scanner), 
 					    igraph_ncol_yyget_leng(scanner)); ;}
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1445 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/ncol-parser.c"
+
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1661,7 +1656,7 @@ yyreturn:
 }
 
 
-#line 124 "/Users/tamas/dev/igraph/igraph/src/io/ncol-parser.y"
+
 
 
 int igraph_ncol_yyerror(YYLTYPE* locp, 
