@@ -180,7 +180,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 23 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
 
 
 /* 
@@ -209,26 +209,21 @@
 #include <string.h>
 #include <math.h>
 
-#include "internal/hacks.h"
 #include "igraph_types.h"
 #include "igraph_memory.h"
 #include "igraph_error.h"
 #include "igraph_attributes.h"
 #include "config.h"
+
 #include "core/math.h"
-
 #include "io/pajek-header.h"
-#include "io/parsers/pajek-parser.h"
+#include "io/parsers/pajek-parser.h" /* it must come first because of YYSTYPE */
+#include "io/parsers/pajek-lexer.h"
+#include "internal/hacks.h"
 
-#define yyscan_t void*
-
-int igraph_pajek_yylex(YYSTYPE* lvalp, YYLTYPE* llocp, 
-		       void* scanner);
 int igraph_pajek_yyerror(YYLTYPE* locp, 
 			 igraph_i_pajek_parsedata_t *context, 
 			 const char *s);
-char *igraph_pajek_yyget_text (yyscan_t yyscanner );
-int igraph_pajek_yyget_leng (yyscan_t yyscanner );
 
 int igraph_i_pajek_add_string_vertex_attribute(const char *name, 
 					       const char *value,
@@ -288,7 +283,7 @@ extern long int igraph_i_pajek_actedge;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 120 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
 {
   long int intnum;
   double   realnum;  
@@ -298,7 +293,7 @@ typedef union YYSTYPE
   } string;  
 }
 /* Line 193 of yacc.c.  */
-#line 302 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/pajek-parser.c"
+
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -323,7 +318,7 @@ typedef struct YYLTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 327 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/pajek-parser.c"
+
 
 #ifdef short
 # undef short
@@ -660,20 +655,20 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   194,   194,   198,   198,   200,   202,   206,   212,   212,
-     214,   215,   216,   216,   219,   221,   226,   227,   231,   237,
-     237,   241,   241,   244,   245,   248,   251,   256,   261,   266,
-     269,   272,   275,   278,   281,   284,   287,   290,   295,   295,
-     299,   299,   303,   303,   307,   307,   312,   312,   319,   321,
-     321,   321,   321,   321,   321,   323,   324,   326,   326,   328,
-     329,   329,   335,   337,   339,   340,   342,   342,   344,   345,
-     345,   351,   353,   355,   355,   359,   359,   362,   363,   368,
-     371,   374,   377,   380,   383,   386,   389,   392,   395,   398,
-     401,   404,   407,   410,   415,   415,   419,   419,   423,   423,
-     427,   427,   431,   431,   437,   439,   441,   441,   443,   443,
-     445,   445,   447,   449,   454,   456,   456,   458,   458,   460,
-     460,   462,   464,   471,   473,   478,   478,   480,   482,   482,
-     484,   504,   507,   510,   510,   512,   514,   516
+       0,   189,   189,   193,   193,   195,   197,   201,   207,   207,
+     209,   210,   211,   211,   214,   216,   221,   222,   226,   232,
+     232,   236,   236,   239,   240,   243,   246,   251,   256,   261,
+     264,   267,   270,   273,   276,   279,   282,   285,   290,   290,
+     294,   294,   298,   298,   302,   302,   307,   307,   314,   316,
+     316,   316,   316,   316,   316,   318,   319,   321,   321,   323,
+     324,   324,   330,   332,   334,   335,   337,   337,   339,   340,
+     340,   346,   348,   350,   350,   354,   354,   357,   358,   363,
+     366,   369,   372,   375,   378,   381,   384,   387,   390,   393,
+     396,   399,   402,   405,   410,   410,   414,   414,   418,   418,
+     422,   422,   426,   426,   432,   434,   436,   436,   438,   438,
+     440,   440,   442,   444,   449,   451,   451,   453,   453,   455,
+     455,   457,   459,   466,   468,   473,   473,   475,   477,   477,
+     479,   499,   502,   505,   505,   507,   509,   511
 };
 #endif
 
@@ -1768,14 +1763,14 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 194 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
   if (context->vcount2 > 0) { igraph_i_pajek_check_bipartite(context); }
  ;}
     break;
 
   case 6:
-#line 202 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
   context->vcount=(yyvsp[(2) - (2)].intnum); 
   context->vcount2=0;
@@ -1783,7 +1778,7 @@ yyreduce:
     break;
 
   case 7:
-#line 206 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
   context->vcount=(yyvsp[(2) - (3)].intnum);
   context->vcount2=(yyvsp[(3) - (3)].intnum);
@@ -1792,22 +1787,22 @@ yyreduce:
     break;
 
   case 12:
-#line 216 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->actvertex=(yyvsp[(1) - (1)].intnum); ;}
     break;
 
   case 13:
-#line 216 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { ;}
     break;
 
   case 14:
-#line 219 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { (yyval.intnum)=(yyvsp[(1) - (1)].intnum); context->mode=1; ;}
     break;
 
   case 15:
-#line 221 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
   igraph_i_pajek_add_string_vertex_attribute("id", (yyvsp[(1) - (1)].string).str, (yyvsp[(1) - (1)].string).len, context);
   igraph_i_pajek_add_string_vertex_attribute("name", (yyvsp[(1) - (1)].string).str, (yyvsp[(1) - (1)].string).len, context);
@@ -1815,7 +1810,7 @@ yyreduce:
     break;
 
   case 17:
-#line 227 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
   igraph_i_pajek_add_numeric_vertex_attribute("x", (yyvsp[(1) - (2)].realnum), context);
   igraph_i_pajek_add_numeric_vertex_attribute("y", (yyvsp[(2) - (2)].realnum), context);
@@ -1823,7 +1818,7 @@ yyreduce:
     break;
 
   case 18:
-#line 231 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
   igraph_i_pajek_add_numeric_vertex_attribute("x", (yyvsp[(1) - (3)].realnum), context);
   igraph_i_pajek_add_numeric_vertex_attribute("y", (yyvsp[(2) - (3)].realnum), context);
@@ -1832,28 +1827,28 @@ yyreduce:
     break;
 
   case 20:
-#line 237 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
   igraph_i_pajek_add_string_vertex_attribute("shape", (yyvsp[(1) - (1)].string).str, (yyvsp[(1) - (1)].string).len, context);
 ;}
     break;
 
   case 24:
-#line 245 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
 	 igraph_i_pajek_add_numeric_vertex_attribute("xfact", (yyvsp[(2) - (2)].realnum), context);
        ;}
     break;
 
   case 25:
-#line 248 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("yfact", (yyvsp[(2) - (2)].realnum), context);
        ;}
     break;
 
   case 26:
-#line 251 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { /* RGB color */
          igraph_i_pajek_add_numeric_vertex_attribute("color-red", (yyvsp[(2) - (4)].realnum), context);
 	 igraph_i_pajek_add_numeric_vertex_attribute("color-green", (yyvsp[(3) - (4)].realnum), context);
@@ -1862,7 +1857,7 @@ yyreduce:
     break;
 
   case 27:
-#line 256 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("framecolor-red", (yyvsp[(2) - (4)].realnum), context);
 	 igraph_i_pajek_add_numeric_vertex_attribute("framecolor-green", (yyvsp[(3) - (4)].realnum), context);
@@ -1871,7 +1866,7 @@ yyreduce:
     break;
 
   case 28:
-#line 261 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("labelcolor-red", (yyvsp[(2) - (4)].realnum), context);
 	 igraph_i_pajek_add_numeric_vertex_attribute("labelcolor-green", (yyvsp[(3) - (4)].realnum), context);
@@ -1880,75 +1875,75 @@ yyreduce:
     break;
 
   case 29:
-#line 266 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("labeldist", (yyvsp[(2) - (2)].realnum), context);
      ;}
     break;
 
   case 30:
-#line 269 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("labeldegree2", (yyvsp[(2) - (2)].realnum), context);
      ;}
     break;
 
   case 31:
-#line 272 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("framewidth", (yyvsp[(2) - (2)].realnum), context);
      ;}
     break;
 
   case 32:
-#line 275 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("fontsize", (yyvsp[(2) - (2)].realnum), context);
      ;}
     break;
 
   case 33:
-#line 278 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {       
          igraph_i_pajek_add_numeric_vertex_attribute("rotation", (yyvsp[(2) - (2)].realnum), context);
      ;}
     break;
 
   case 34:
-#line 281 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("radius", (yyvsp[(2) - (2)].realnum), context);
      ;}
     break;
 
   case 35:
-#line 284 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("diamondratio", (yyvsp[(2) - (2)].realnum), context);
      ;}
     break;
 
   case 36:
-#line 287 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("labeldegree", (yyvsp[(2) - (2)].realnum), context);
      ;}
     break;
 
   case 37:
-#line 290 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          igraph_i_pajek_add_numeric_vertex_attribute("vertexsize", (yyvsp[(2) - (2)].realnum), context);
      ;}
     break;
 
   case 38:
-#line 295 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=3; ;}
     break;
 
   case 39:
-#line 295 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
          context->mode=1;
 	 igraph_i_pajek_add_string_vertex_attribute("font", (yyvsp[(3) - (3)].string).str, (yyvsp[(3) - (3)].string).len, context);
@@ -1956,12 +1951,12 @@ yyreduce:
     break;
 
   case 40:
-#line 299 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=3; ;}
     break;
 
   case 41:
-#line 299 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          context->mode=1;
 	 igraph_i_pajek_add_string_vertex_attribute("url", (yyvsp[(3) - (3)].string).str, (yyvsp[(3) - (3)].string).len, context);
@@ -1969,12 +1964,12 @@ yyreduce:
     break;
 
   case 42:
-#line 303 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=3; ;}
     break;
 
   case 43:
-#line 303 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          context->mode=1;
 	 igraph_i_pajek_add_string_vertex_attribute("color", (yyvsp[(3) - (3)].string).str, (yyvsp[(3) - (3)].string).len, context);
@@ -1982,12 +1977,12 @@ yyreduce:
     break;
 
   case 44:
-#line 307 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=3; ;}
     break;
 
   case 45:
-#line 307 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          context->mode=1;
 	 igraph_i_pajek_add_string_vertex_attribute("framecolor", 
@@ -1996,12 +1991,12 @@ yyreduce:
     break;
 
   case 46:
-#line 312 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=3; ;}
     break;
 
   case 47:
-#line 312 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
          context->mode=1;
 	 igraph_i_pajek_add_string_vertex_attribute("labelcolor", 
@@ -2010,65 +2005,65 @@ yyreduce:
     break;
 
   case 48:
-#line 319 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { (yyval.string)=(yyvsp[(1) - (1)].string); ;}
     break;
 
   case 55:
-#line 323 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->directed=1; ;}
     break;
 
   case 56:
-#line 324 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->directed=1; ;}
     break;
 
   case 60:
-#line 329 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->actedge++;
 	                  context->mode=2; ;}
     break;
 
   case 61:
-#line 330 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
   igraph_vector_push_back(context->vector, (yyvsp[(1) - (6)].intnum)-1);
   igraph_vector_push_back(context->vector, (yyvsp[(2) - (6)].intnum)-1); ;}
     break;
 
   case 64:
-#line 339 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->directed=0; ;}
     break;
 
   case 65:
-#line 340 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->directed=0; ;}
     break;
 
   case 69:
-#line 345 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->actedge++; 
 	                    context->mode=2; ;}
     break;
 
   case 70:
-#line 346 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
   igraph_vector_push_back(context->vector, (yyvsp[(1) - (6)].intnum)-1);
   igraph_vector_push_back(context->vector, (yyvsp[(2) - (6)].intnum)-1); ;}
     break;
 
   case 74:
-#line 355 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
   igraph_i_pajek_add_numeric_edge_attribute("weight", (yyvsp[(1) - (1)].realnum), context);
 ;}
     break;
 
   case 78:
-#line 363 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("color-red", (yyvsp[(2) - (4)].realnum), context);
        igraph_i_pajek_add_numeric_edge_attribute("color-green", (yyvsp[(3) - (4)].realnum), context);
@@ -2077,117 +2072,117 @@ yyreduce:
     break;
 
   case 79:
-#line 368 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
        igraph_i_pajek_add_numeric_edge_attribute("arrowsize", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 80:
-#line 371 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("edgewidth", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 81:
-#line 374 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("hook1", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 82:
-#line 377 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("hook2", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 83:
-#line 380 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("angle1", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 84:
-#line 383 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("angle2", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 85:
-#line 386 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("velocity1", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 86:
-#line 389 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("velocity2", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 87:
-#line 392 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("arrowpos", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 88:
-#line 395 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("labelpos", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 89:
-#line 398 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("labelangle", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 90:
-#line 401 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("labelangle2", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 91:
-#line 404 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("labeldegree", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 92:
-#line 407 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {		/* what is this??? */
        igraph_i_pajek_add_numeric_edge_attribute("arrowsize", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 93:
-#line 410 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
        igraph_i_pajek_add_numeric_edge_attribute("fontsize", (yyvsp[(2) - (2)].realnum), context);
    ;}
     break;
 
   case 94:
-#line 415 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=4; ;}
     break;
 
   case 95:
-#line 415 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
       context->mode=2;
       igraph_i_pajek_add_string_edge_attribute("arrowtype", (yyvsp[(3) - (3)].string).str, (yyvsp[(3) - (3)].string).len, context);
@@ -2195,12 +2190,12 @@ yyreduce:
     break;
 
   case 96:
-#line 419 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=4; ;}
     break;
 
   case 97:
-#line 419 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
       context->mode=2;
       igraph_i_pajek_add_string_edge_attribute("linepattern", (yyvsp[(3) - (3)].string).str, (yyvsp[(3) - (3)].string).len, context);
@@ -2208,12 +2203,12 @@ yyreduce:
     break;
 
   case 98:
-#line 423 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=4; ;}
     break;
 
   case 99:
-#line 423 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
       context->mode=2;
       igraph_i_pajek_add_string_edge_attribute("label", (yyvsp[(3) - (3)].string).str, (yyvsp[(3) - (3)].string).len, context);
@@ -2221,12 +2216,12 @@ yyreduce:
     break;
 
   case 100:
-#line 427 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=4; ;}
     break;
 
   case 101:
-#line 427 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
       context->mode=2;
       igraph_i_pajek_add_string_edge_attribute("labelcolor", (yyvsp[(3) - (3)].string).str, (yyvsp[(3) - (3)].string).len, context);
@@ -2234,12 +2229,12 @@ yyreduce:
     break;
 
   case 102:
-#line 431 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=4; ;}
     break;
 
   case 103:
-#line 431 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
       context->mode=2;
       igraph_i_pajek_add_string_edge_attribute("color", (yyvsp[(3) - (3)].string).str, (yyvsp[(3) - (3)].string).len, context);
@@ -2247,22 +2242,22 @@ yyreduce:
     break;
 
   case 104:
-#line 437 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=2; (yyval.string)=(yyvsp[(1) - (1)].string); ;}
     break;
 
   case 105:
-#line 439 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->directed=1; ;}
     break;
 
   case 112:
-#line 447 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=0; context->actfrom=labs((yyvsp[(1) - (1)].intnum))-1; ;}
     break;
 
   case 113:
-#line 449 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
   igraph_vector_push_back(context->vector, context->actfrom); 
   igraph_vector_push_back(context->vector, labs((yyvsp[(1) - (1)].intnum))-1); 
@@ -2270,17 +2265,17 @@ yyreduce:
     break;
 
   case 114:
-#line 454 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->directed=0; ;}
     break;
 
   case 121:
-#line 462 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->mode=0; context->actfrom=labs((yyvsp[(1) - (1)].intnum))-1; ;}
     break;
 
   case 122:
-#line 464 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { 
   igraph_vector_push_back(context->vector, context->actfrom); 
   igraph_vector_push_back(context->vector, labs((yyvsp[(1) - (1)].intnum))-1); 
@@ -2288,7 +2283,7 @@ yyreduce:
     break;
 
   case 124:
-#line 473 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->actfrom=0; 
                          context->actto=0; 
                          context->directed=(context->vcount2==0);
@@ -2296,12 +2291,12 @@ yyreduce:
     break;
 
   case 127:
-#line 480 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { context->actfrom++; context->actto=0; ;}
     break;
 
   case 130:
-#line 484 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     {
   if ((yyvsp[(1) - (1)].realnum) != 0) {
     if (context->vcount2==0) {
@@ -2322,38 +2317,38 @@ yyreduce:
     break;
 
   case 131:
-#line 504 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { (yyval.intnum)=igraph_pajek_get_number(igraph_pajek_yyget_text(scanner),
 					  igraph_pajek_yyget_leng(scanner)); ;}
     break;
 
   case 132:
-#line 507 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { (yyval.realnum)=igraph_pajek_get_number(igraph_pajek_yyget_text(scanner),
 					  igraph_pajek_yyget_leng(scanner)); ;}
     break;
 
   case 135:
-#line 512 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { (yyval.string).str=igraph_pajek_yyget_text(scanner); 
               (yyval.string).len=igraph_pajek_yyget_leng(scanner); ;}
     break;
 
   case 136:
-#line 514 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { (yyval.string).str=igraph_pajek_yyget_text(scanner); 
               (yyval.string).len=igraph_pajek_yyget_leng(scanner); ;}
     break;
 
   case 137:
-#line 516 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
     { (yyval.string).str=igraph_pajek_yyget_text(scanner)+1; 
                (yyval.string).len=igraph_pajek_yyget_leng(scanner)-2; ;}
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 2357 "/Users/tamas/dev/igraph/igraph/build/src/io/parsers/pajek-parser.c"
+
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2573,7 +2568,7 @@ yyreturn:
 }
 
 
-#line 519 "/Users/tamas/dev/igraph/igraph/src/io/pajek-parser.y"
+
 
 
 int igraph_pajek_yyerror(YYLTYPE* locp, 
